Installing cartouche — Cartouche 1.1 documentation

### Navigation

- index
- next |
- previous |
- Cartouche 1.1 documentation »

# Installing `cartouche`

`cartouche` is available on the Python Package Index (PyPI) and can be installed with `easy_install` so long as you have setuptools installed already:

    $ easy_install cartouche

Alternatively, you can download and unpack the source distribution from the `cartouche` downloads page or PyPI. You should then unpack the source distribution into a temporary directory and run the setup script which will install `cartouche` into the current Python environment, for example:

    $ tar xzf cartouche-1.1.tar.gz
    $ cd cartouche-1.1
    $ python setup.py install

### Navigation

- index
- next |
- previous |
- Cartouche 1.1 documentation »